@@ -2,9 +2,11 @@
 pub mod cli;
 mod config;
 mod error;
+mod metadata;
 pub mod oauth1;
 mod params;
 mod requester;
+mod response;
 mod rest_api;
 mod suiteql;
 
